Crate balius_sdk

Crate balius_sdk 

Re-exports

pub use _internal::Worker;
pub use crate::_internal::global_get_public_keys as get_public_keys;
pub use balius_macros as macros;

Modules

_internal
Internal functions to be used by the generated code
http
An HTTP implementation
logging
A tracing implementation which sends logs to the server
txbuilder
Transaction builder artifacts
wit

Macros

constr
define_asset_class

Structs

Ack
Config
FnHandler
Json
NewTx
Params
Tx
Utxo
UtxoMatcher

Enums

Error

Type Aliases

WorkerResult

Attribute Macros

main
Macro to mark the main function for the worker