#[repr(C)]pub struct RequestOptions {
pub connect_timeout: Option<Duration>,
pub first_byte_timeout: Option<Duration>,
pub between_bytes_timeout: Option<Duration>,
}Fields
connect_timeout: Option<Duration>The timeout for the initial connect to the HTTP Server.
first_byte_timeout: Option<Duration>The timeout for receiving the first byte of the Response body.
between_bytes_timeout: Option<Duration>The timeout for receiving subsequent chunks of bytes in the Response body stream.